@@ -1,10 +1,10 @@
-/* $Id: fxdd.c,v 1.84.2.1 2002/03/16 00:50:12 brianp Exp $ */
+/* $Id: fxdd.c,v 1.84.2.3 2002/06/24 17:37:53 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  4.0
+ * Version:  4.0.3
  *
- * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
+ * Copyright (C) 1999-2002  Brian Paul   All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -47,6 +47,7 @@
 #include "extensions.h"
 #include "texstore.h"
 #include "swrast/swrast.h"
+#include "swrast/s_context.h"
 #include "swrast_setup/swrast_setup.h"
 #include "tnl/tnl.h"
 #include "tnl/t_context.h"
@@ -264,7 +265,7 @@ fxDDClear(GLcontext * ctx, GLbitfield mask, GLboolean all,
 
 /* Set the buffer used for drawing */
 /* XXX support for separate read/draw buffers hasn't been tested */
-static GLboolean
+static void
 fxDDSetDrawBuffer(GLcontext * ctx, GLenum mode)
 {
    fxMesaContext fxMesa = (fxMesaContext) ctx->DriverCtx;
@@ -276,26 +277,22 @@ fxDDSetDrawBuffer(GLcontext * ctx, GLenum mode)
    if (mode == GL_FRONT_LEFT) {
       fxMesa->currentFB = GR_BUFFER_FRONTBUFFER;
       FX_grRenderBuffer(fxMesa->currentFB);
-      return GL_TRUE;
    }
    else if (mode == GL_BACK_LEFT) {
       fxMesa->currentFB = GR_BUFFER_BACKBUFFER;
       FX_grRenderBuffer(fxMesa->currentFB);
-      return GL_TRUE;
    }
    else if (mode == GL_NONE) {
       FX_grColorMask(FXFALSE, FXFALSE);
-      return GL_TRUE;
    }
    else {
-      return GL_FALSE;
+      /* we'll need a software fallback */
+      /* XXX not implemented */
    }
 }
 
 
 
-
-
 static void
 fxDDDrawBitmap(GLcontext * ctx, GLint px, GLint py,
 	       GLsizei width, GLsizei height,
@@ -307,6 +304,7 @@ fxDDDrawBitmap(GLcontext * ctx, GLint px, GLint py,
    FxU16 color;
    const struct gl_pixelstore_attrib *finalUnpack;
    struct gl_pixelstore_attrib scissoredUnpack;
+   SWcontext *swrast = SWRAST_CONTEXT(ctx);
 
    /* check if there's any raster operations enabled which we can't handle */
    if (ctx->Color.AlphaEnabled ||
@@ -317,12 +315,11 @@ fxDDDrawBitmap(GLcontext * ctx, GLint px, GLint py,
        ctx->Stencil.Enabled ||
        ctx->Scissor.Enabled ||
        (ctx->DrawBuffer->UseSoftwareAlphaBuffers &&
-	ctx->Color.ColorMask[ACOMP]) || ctx->Color.MultiDrawBuffer) {
+	ctx->Color.ColorMask[ACOMP]) || (swrast->_RasterMask & MULTI_DRAW_BIT)) {
       _swrast_Bitmap(ctx, px, py, width, height, unpack, bitmap);
       return;
    }
 
-
    if (ctx->Scissor.Enabled) {
       /* This is a bit tricky, but by carefully adjusting the px, py,
        * width, height, skipPixels and skipRows values we can do
@@ -824,12 +821,13 @@ GLboolean
 fx_check_IsInHardware(GLcontext * ctx)
 {
    fxMesaContext fxMesa = (fxMesaContext) ctx->DriverCtx;
+   SWcontext *swrast = SWRAST_CONTEXT(ctx);
 
    if (ctx->RenderMode != GL_RENDER)
       return GL_FALSE;
 
    if (ctx->Stencil.Enabled ||
-       ctx->Color.MultiDrawBuffer ||
+       (swrast->_RasterMask & MULTI_DRAW_BIT) ||
        ((ctx->Color.BlendEnabled)
 	&& (ctx->Color.BlendEquation != GL_FUNC_ADD_EXT))
        || ((ctx->Color.ColorLogicOpEnabled)
