@@ -24,6 +24,13 @@
 
 /*
  * $Log: colors.h,v $
+ * Revision 1.1.1.1.8.2  2002/01/15 16:47:37  kschultz
+ * Fixed pixel color component problem and clear code for 24-bit Windows
+ * devices.  (Jeff Lewis)
+ *
+ * Revision 1.1.1.1.8.1  2002/01/15 16:12:15  kschultz
+ * Remove trailing CR's from most of the lines.  No logical changes.
+ *
  * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
  * Imported sources
  *
@@ -39,6 +46,13 @@
 
 /*
  * $Log: colors.h,v $
+ * Revision 1.1.1.1.8.2  2002/01/15 16:47:37  kschultz
+ * Fixed pixel color component problem and clear code for 24-bit Windows
+ * devices.  (Jeff Lewis)
+ *
+ * Revision 1.1.1.1.8.1  2002/01/15 16:12:15  kschultz
+ * Remove trailing CR's from most of the lines.  No logical changes.
+ *
  * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
  * Imported sources
  *
@@ -54,6 +68,13 @@
  
 /*
  * $Log: colors.h,v $
+ * Revision 1.1.1.1.8.2  2002/01/15 16:47:37  kschultz
+ * Fixed pixel color component problem and clear code for 24-bit Windows
+ * devices.  (Jeff Lewis)
+ *
+ * Revision 1.1.1.1.8.1  2002/01/15 16:12:15  kschultz
+ * Remove trailing CR's from most of the lines.  No logical changes.
+ *
  * Revision 1.1.1.1  1999/08/19 00:55:42  jtg
  * Imported sources
  *
@@ -117,7 +138,8 @@ char ColorMap16[] = {
 #else
 #define BGR16(r,g,b)	((WORD)(((BYTE)(ColorMap16[b]) | ((BYTE)(ColorMap16[g]) << 5)) | (((WORD)(BYTE)(ColorMap16[r])) << 10)))
 #endif
-#define BGR24(r,g,b)	(unsigned long)(((DWORD)(((BYTE)(b)|((WORD)((BYTE)(g))<<8))|(((DWORD)(BYTE)(r))<<16))) << 8)
+#define BGR24(r,g,b) (unsigned long)((DWORD)(((BYTE)(b)|((WORD)((BYTE)(g))<<8))|(((DWORD)(BYTE)(r))<<16)))
+
 #define BGR32(r,g,b)	(unsigned long)((DWORD)(((BYTE)(b)|((WORD)((BYTE)(g))<<8))|(((DWORD)(BYTE)(r))<<16)))
 
 
@@ -496,4 +518,4 @@ char unsigned const aWinGHalftoneTranslation[216] =
   225,
   226,
   255,
-};
\ No newline at end of file
+};
