@@ -1,8 +1,8 @@
-/* $Id: xm_dd.c,v 1.26.2.5 2002/03/19 16:47:56 brianp Exp $ */
+/* $Id: xm_dd.c,v 1.26.2.7 2002/06/19 21:50:14 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  4.0.2
+ * Version:  4.0.3
  *
  * Copyright (C) 1999-2002  Brian Paul   All Rights Reserved.
  *
@@ -61,19 +61,20 @@ get_buffer_size( GLframebuffer *buffer, GLuint *width, GLuint *height )
     */
    const XMesaBuffer xmBuffer = (XMesaBuffer) buffer;
    unsigned int winwidth, winheight;
-#ifndef XFree86Server
+#ifdef XFree86Server
+   /* XFree86 GLX renderer */
+   winwidth = xmBuffer->frontbuffer->width;
+   winheight = xmBuffer->frontbuffer->height;
+#else
    Window root;
    int winx, winy;
    unsigned int bw, d;
 
    _glthread_LOCK_MUTEX(_xmesa_lock);
+   XSync(xmBuffer->xm_visual->display, 0); /* added for Chromium */
    XGetGeometry( xmBuffer->xm_visual->display, xmBuffer->frontbuffer, &root,
 		 &winx, &winy, &winwidth, &winheight, &bw, &d );
    _glthread_UNLOCK_MUTEX(_xmesa_lock);
-#else
-   /* XFree86 GLX renderer */
-   winwidth = xmBuffer->frontbuffer->width;
-   winheight = xmBuffer->frontbuffer->height;
 #endif
 
    (void)kernel8;		/* Muffle compiler */
@@ -115,9 +116,7 @@ flush( GLcontext *ctx )
 }
 
 
-
-
-static GLboolean
+static void
 set_draw_buffer( GLcontext *ctx, GLenum mode )
 {
    const XMesaContext xmesa = (XMesaContext) ctx->DriverCtx;
@@ -125,7 +124,6 @@ set_draw_buffer( GLcontext *ctx, GLenum mode )
       /* write to front buffer */
       xmesa->xm_buffer->buffer = xmesa->xm_buffer->frontbuffer;
       xmesa_update_span_funcs(ctx);
-      return GL_TRUE;
    }
    else if (mode==GL_BACK_LEFT && xmesa->xm_buffer->db_state) {
       /* write to back buffer */
@@ -141,10 +139,11 @@ set_draw_buffer( GLcontext *ctx, GLenum mode )
          xmesa->xm_buffer->buffer = xmesa->xm_buffer->frontbuffer;
       }
       xmesa_update_span_funcs(ctx);
-      return GL_TRUE;
    }
    else {
-      return GL_FALSE;
+      /* the swrast->_RasterMask MULTI_DRAW_BIT will be set and
+       * we'll fall back to swrast to draw points/lines/triangles.
+       */
    }
 }
 
