@@ -1,4 +1,4 @@
-/* $Id: drawpix.c,v 1.56.2.1 2001/12/13 19:12:30 brianp Exp $ */
+/* $Id: drawpix.c,v 1.56.2.2 2002/01/15 21:50:15 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -52,6 +52,11 @@ _mesa_DrawPixels( GLsizei width, GLsizei height,
    GET_CURRENT_CONTEXT(ctx);
    ASSERT_OUTSIDE_BEGIN_END_AND_FLUSH(ctx);
 
+   if (width < 0 || height < 0) {
+      _mesa_error( ctx, GL_INVALID_VALUE, "glDrawPixels(width or height < 0" );
+      return;
+   }
+
    if (ctx->RenderMode==GL_RENDER) {
       GLint x, y;
       if (!pixels || !ctx->Current.RasterPosValid) {
@@ -97,6 +102,11 @@ _mesa_ReadPixels( GLint x, GLint y, GLsizei width, GLsizei height,
    GET_CURRENT_CONTEXT(ctx);
    ASSERT_OUTSIDE_BEGIN_END_AND_FLUSH(ctx);
 
+   if (width < 0 || height < 0) {
+      _mesa_error( ctx, GL_INVALID_VALUE, "glReadPixels(width or height < 0)" );
+      return;
+   }
+
    if (!pixels) {
       _mesa_error( ctx, GL_INVALID_VALUE, "glReadPixels(pixels)" );
       return;
@@ -121,7 +131,7 @@ _mesa_CopyPixels( GLint srcx, GLint srcy, GLsizei width, GLsizei height,
    ASSERT_OUTSIDE_BEGIN_END_AND_FLUSH(ctx);
 
    if (width < 0 || height < 0) {
-      _mesa_error( ctx, GL_INVALID_VALUE, "glCopyPixels" );
+      _mesa_error( ctx, GL_INVALID_VALUE, "glCopyPixels(width or height < 0)" );
       return;
    }
 
@@ -170,9 +180,8 @@ _mesa_Bitmap( GLsizei width, GLsizei height,
    GET_CURRENT_CONTEXT(ctx);
    ASSERT_OUTSIDE_BEGIN_END_AND_FLUSH(ctx);
 
-   /* Error checking */
    if (width < 0 || height < 0) {
-      _mesa_error( ctx, GL_INVALID_VALUE, "glBitmap" );
+      _mesa_error( ctx, GL_INVALID_VALUE, "glBitmap(width or height < 0)" );
       return;
    }
 
