@@ -1,10 +1,10 @@
-/* $Id: s_accum.c,v 1.13 2001/09/19 20:30:44 kschultz Exp $ */
+/* $Id: s_accum.c,v 1.13.2.2 2002/03/19 16:42:41 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  3.5
+ * Version:  4.0.2
  *
- * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
+ * Copyright (C) 1999-2002  Brian Paul   All Rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -66,39 +66,38 @@
 #define USE_OPTIMIZED_ACCUM   /* enable the optimization */
 #endif
 
-
-
 void
-_mesa_alloc_accum_buffer( GLcontext *ctx )
+_mesa_alloc_accum_buffer( GLframebuffer *buffer )
 {
-   SWcontext *swrast = SWRAST_CONTEXT(ctx);
+   GET_CURRENT_CONTEXT(ctx);
    GLint n;
 
-   if (ctx->DrawBuffer->Accum) {
-      FREE( ctx->DrawBuffer->Accum );
-      ctx->DrawBuffer->Accum = NULL;
+   if (buffer->Accum) {
+      MESA_PBUFFER_FREE( buffer->Accum );
+      buffer->Accum = NULL;
    }
 
    /* allocate accumulation buffer if not already present */
-   n = ctx->DrawBuffer->Width * ctx->DrawBuffer->Height * 4 * sizeof(GLaccum);
-   ctx->DrawBuffer->Accum = (GLaccum *) MALLOC( n );
-   if (!ctx->DrawBuffer->Accum) {
+   n = buffer->Width * buffer->Height * 4 * sizeof(GLaccum);
+   buffer->Accum = (GLaccum *) MESA_PBUFFER_ALLOC( n );
+   if (!buffer->Accum) {
       /* unable to setup accumulation buffer */
-      _mesa_error( ctx, GL_OUT_OF_MEMORY, "glAccum" );
+      _mesa_error( NULL, GL_OUT_OF_MEMORY, "glAccum" );
    }
+
+   if (ctx) {
+      SWcontext *swrast = SWRAST_CONTEXT(ctx);
+      /* XXX these fields should probably be in the GLframebuffer */
 #ifdef USE_OPTIMIZED_ACCUM
-   swrast->_IntegerAccumMode = GL_TRUE;
+      swrast->_IntegerAccumMode = GL_TRUE;
 #else
-   swrast->_IntegerAccumMode = GL_FALSE;
+      swrast->_IntegerAccumMode = GL_FALSE;
 #endif
-   swrast->_IntegerAccumScaler = 0.0;
+      swrast->_IntegerAccumScaler = 0.0;
+   }
 }
 
 
-
-
-
-
 /*
  * This is called when we fall out of optimized/unscaled accum buffer mode.
  * That is, we convert each unscaled accum buffer value into a scaled value
@@ -243,7 +242,6 @@ _swrast_Accum( GLcontext *ctx, GLenum op, GLfloat value,
    GLchan rgba[MAX_WIDTH][4];
    const GLuint colorMask = *((GLuint *) &ctx->Color.ColorMask);
 
-
    if (SWRAST_CONTEXT(ctx)->NewState)
       _swrast_validate_derived( ctx );
 
