@@ -1,8 +1,8 @@
-/* $Id: s_triangle.c,v 1.39.2.2 2001/12/19 01:13:12 brianp Exp $ */
+/* $Id: s_triangle.c,v 1.39.2.5 2002/01/30 16:45:29 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  4.0.1
+ * Version:  4.0.2
  *
  * Copyright (C) 1999-2001  Brian Paul   All Rights Reserved.
  *
@@ -339,7 +339,7 @@ struct affine_info
    GLint smask, tmask;
    GLint twidth_log2;
    const GLchan *texture;
-   GLchan er, eg, eb, ea;
+   GLfixed er, eg, eb, ea;
    GLint tbytesline, tsize;
    GLint fixedToDepthShift;
 };
@@ -430,7 +430,12 @@ affine_span(GLcontext *ctx, struct triangle_span *span,
 
 /* shortcuts */
 
-#define NEAREST_RGB_REPLACE  NEAREST_RGB;REPLACE
+#define NEAREST_RGB_REPLACE		\
+   NEAREST_RGB;				\
+   dest[0] = sample[0];			\
+   dest[1] = sample[1];			\
+   dest[2] = sample[2];			\
+   dest[3] = FixedToInt(span->alpha);
 
 #define NEAREST_RGBA_REPLACE  COPY_CHAN4(dest, tex00)
 
@@ -641,10 +646,10 @@ static void affine_textured_triangle( GLcontext *ctx,
 									\
    if (info.envmode == GL_BLEND) {					\
       /* potential off-by-one error here? (1.0f -> 2048 -> 0) */	\
-      info.er = FloatToFixed(unit->EnvColor[RCOMP]);			\
-      info.eg = FloatToFixed(unit->EnvColor[GCOMP]);			\
-      info.eb = FloatToFixed(unit->EnvColor[BCOMP]);			\
-      info.ea = FloatToFixed(unit->EnvColor[ACOMP]);			\
+      info.er = FloatToFixed(unit->EnvColor[RCOMP] * CHAN_MAXF);	\
+      info.eg = FloatToFixed(unit->EnvColor[GCOMP] * CHAN_MAXF);	\
+      info.eb = FloatToFixed(unit->EnvColor[BCOMP] * CHAN_MAXF);	\
+      info.ea = FloatToFixed(unit->EnvColor[ACOMP] * CHAN_MAXF);	\
    }									\
    if (!info.texture) {							\
       /* this shouldn't happen */					\
@@ -688,7 +693,7 @@ struct persp_info
    GLint smask, tmask;
    GLint twidth_log2;
    const GLchan *texture;
-   GLchan er, eg, eb, ea;   /* texture env color */
+   GLfixed er, eg, eb, ea;   /* texture env color */
    GLint tbytesline, tsize;
    GLint fixedToDepthShift;
 };
@@ -933,10 +938,10 @@ static void persp_textured_triangle( GLcontext *ctx,
 									\
    if (info.envmode == GL_BLEND) {					\
       /* potential off-by-one error here? (1.0f -> 2048 -> 0) */	\
-      info.er = FloatToFixed(unit->EnvColor[RCOMP]);			\
-      info.eg = FloatToFixed(unit->EnvColor[GCOMP]);			\
-      info.eb = FloatToFixed(unit->EnvColor[BCOMP]);			\
-      info.ea = FloatToFixed(unit->EnvColor[ACOMP]);			\
+      info.er = FloatToFixed(unit->EnvColor[RCOMP] * CHAN_MAXF);	\
+      info.eg = FloatToFixed(unit->EnvColor[GCOMP] * CHAN_MAXF);	\
+      info.eb = FloatToFixed(unit->EnvColor[BCOMP] * CHAN_MAXF);	\
+      info.ea = FloatToFixed(unit->EnvColor[ACOMP] * CHAN_MAXF);	\
    }									\
    if (!info.texture) {							\
       /* this shouldn't happen */					\
@@ -1712,7 +1717,7 @@ _swrast_choose_triangle( GLcontext *ctx )
 		  }
 	       }
 	       else {
-#if CHAN_TYPE == GL_FLOAT
+#if (CHAN_BITS == 16 || CHAN_BITS == 32)
                   USE(general_textured_triangle);
 #else
                   USE(affine_textured_triangle);
@@ -1720,7 +1725,7 @@ _swrast_choose_triangle( GLcontext *ctx )
 	       }
 	    }
 	    else {
-#if CHAN_TYPE == GL_FLOAT
+#if (CHAN_BITS == 16 || CHAN_BITS == 32)
                USE(general_textured_triangle);
 #else
                USE(persp_textured_triangle);
