@@ -1,4 +1,4 @@
-/* $Id: t_dd_dmatmp.h,v 1.10.2.2 2001/12/11 15:12:57 keithw Exp $ */
+/* $Id: t_dd_dmatmp.h,v 1.10.2.3 2002/02/12 17:37:27 keithw Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -202,7 +202,7 @@ static void TAG(render_line_strip_verts)( GLcontext *ctx,
       if (currentsz < 8)
 	 currentsz = dmasz;
 
-      for (j = start; j < count - 1; j += nr - 1 ) {
+      for (j = start; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j );
 	 EMIT_VERTS( ctx, j, nr );
 	 currentsz = dmasz;
@@ -243,7 +243,7 @@ static void TAG(render_line_loop_verts)( GLcontext *ctx,
       if (currentsz < 8)
 	 currentsz = dmasz;
 
-      for ( ; j < count - 1; j += nr - 1 ) {
+      for ( ; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j );
 	 EMIT_VERTS( ctx, j, nr );
 	 currentsz = dmasz;
@@ -307,7 +307,7 @@ static void TAG(render_tri_strip_verts)( GLcontext *ctx,
       currentsz = GET_CURRENT_VB_MAX_VERTS();
 
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
@@ -324,7 +324,7 @@ static void TAG(render_tri_strip_verts)( GLcontext *ctx,
       dmasz -= (dmasz & 1);
       currentsz -= (currentsz & 1);
 
-      for (j = start ; j < count - 2; j += nr - 2 ) {
+      for (j = start ; j + 2 < count; j += nr - 2 ) {
 	 nr = MIN2( currentsz, count - j );
 	 EMIT_VERTS( ctx, j, nr );
 	 currentsz = dmasz;
@@ -352,11 +352,11 @@ static void TAG(render_tri_fan_verts)( GLcontext *ctx,
       INIT(GL_TRIANGLE_FAN);
 
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
-      for (j = start + 1 ; j < count - 1; j += nr - 1 ) {
+      for (j = start + 1 ; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j + 1 );
 	 EMIT_VERTS( ctx, start, 1 );
 	 EMIT_VERTS( ctx, j, nr - 1 );
@@ -390,11 +390,11 @@ static void TAG(render_poly_verts)( GLcontext *ctx,
       INIT(GL_POLYGON);
 
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
-      for (j = start + 1 ; j < count - 1 ; j += nr - 1 ) {
+      for (j = start + 1 ; j + 1 < count ; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j + 1 );
 	 EMIT_VERTS( ctx, start, 1 );
 	 EMIT_VERTS( ctx, j, nr - 1 );
@@ -430,14 +430,14 @@ static void TAG(render_quad_strip_verts)( GLcontext *ctx,
       currentsz = GET_CURRENT_VB_MAX_VERTS();
 
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
       dmasz -= (dmasz & 2);
       currentsz -= (currentsz & 2);
 
-      for (j = start ; j < count - 3; j += nr - 2 ) {
+      for (j = start ; j + 3 < count; j += nr - 2 ) {
 	 nr = MIN2( currentsz, count - j );
 	 EMIT_VERTS( ctx, j, nr );
 	 currentsz = dmasz;
@@ -445,7 +445,7 @@ static void TAG(render_quad_strip_verts)( GLcontext *ctx,
 
       FINISH;
 
-   } else if (HAVE_TRI_STRIPS && ctx->_TriangleCaps & DD_FLATSHADE) {
+   } else if (HAVE_TRI_STRIPS && (ctx->_TriangleCaps & DD_FLATSHADE)) {
       if (TAG(emit_elt_verts)( ctx, start, count )) {
 	 LOCAL_VARS;
 	 int dmasz = GET_SUBSEQUENT_VB_MAX_ELTS();
@@ -471,7 +471,7 @@ static void TAG(render_quad_strip_verts)( GLcontext *ctx,
 	 currentsz = currentsz/6*2;
 	 dmasz = dmasz/6*2;
 
-	 for (j = start; j < count - 3; j += nr - 2 ) {
+	 for (j = start; j + 3 < count; j += nr - 2 ) {
 	    nr = MIN2( currentsz, count - j );
 	    if (nr >= 4) {
 	       GLint quads = (nr/2)-1;
@@ -519,11 +519,11 @@ static void TAG(render_quad_strip_verts)( GLcontext *ctx,
       count -= (count-start) & 1;
 
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
-      for (j = start; j < count - 3; j += nr - 2 ) {
+      for (j = start; j + 3 < count; j += nr - 2 ) {
 	 nr = MIN2( currentsz, count - j );
 	 EMIT_VERTS( ctx, j, nr );
 	 currentsz = dmasz;
@@ -740,7 +740,7 @@ static void TAG(render_line_strip_elts)( GLcontext *ctx,
       if (currentsz < 8)
 	 currentsz = dmasz;
 
-      for (j = start; j < count - 1; j += nr - 1 ) {
+      for (j = start; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j );
 	 TAG(emit_elts)( ctx, elts+j, nr );
 	 NEW_PRIMITIVE();
@@ -776,7 +776,7 @@ static void TAG(render_line_loop_elts)( GLcontext *ctx,
 
       currentsz = GET_CURRENT_VB_MAX_ELTS();
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
@@ -785,7 +785,7 @@ static void TAG(render_line_loop_elts)( GLcontext *ctx,
       currentsz--;
       dmasz--;
 
-      for ( ; j < count - 1; j += nr - 1 ) {
+      for ( ; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j );
 /*  	 NEW_PRIMITIVE(); */
 	 TAG(emit_elts)( ctx, elts+j, nr );
@@ -858,7 +858,7 @@ static void TAG(render_tri_strip_elts)( GLcontext *ctx,
 
       currentsz = GET_CURRENT_VB_MAX_ELTS();
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
@@ -871,7 +871,7 @@ static void TAG(render_tri_strip_elts)( GLcontext *ctx,
       dmasz -= (dmasz & 1);
       currentsz -= (currentsz & 1);
 
-      for (j = start ; j < count - 2; j += nr - 2 ) {
+      for (j = start ; j + 2 < count; j += nr - 2 ) {
 	 nr = MIN2( currentsz, count - j );
 	 TAG(emit_elts)( ctx, elts+j, nr );
 	 NEW_PRIMITIVE();
@@ -900,11 +900,11 @@ static void TAG(render_tri_fan_elts)( GLcontext *ctx,
 
       currentsz = GET_CURRENT_VB_MAX_ELTS();
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
-      for (j = start + 1 ; j < count - 1; j += nr - 1 ) {
+      for (j = start + 1 ; j + 1 < count; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j + 1 );
 	 TAG(emit_elts)( ctx, elts+start, 1 );
 	 TAG(emit_elts)( ctx, elts+j, nr - 1 );
@@ -936,11 +936,11 @@ static void TAG(render_poly_elts)( GLcontext *ctx,
 
       currentsz = GET_CURRENT_VB_MAX_ELTS();
       if (currentsz < 8) {
-	 FIRE_VERTICES();
+	 NEW_BUFFER();
 	 currentsz = dmasz;
       }
 
-      for (j = start + 1 ; j < count - 1 ; j += nr - 1 ) {
+      for (j = start + 1 ; j + 1 < count ; j += nr - 1 ) {
 	 nr = MIN2( currentsz, count - j + 1 );
 	 TAG(emit_elts)( ctx, elts+start, 1 );
 	 TAG(emit_elts)( ctx, elts+j, nr - 1 );
@@ -984,7 +984,7 @@ static void TAG(render_quad_strip_elts)( GLcontext *ctx,
 	 currentsz = currentsz/6*2;
 	 dmasz = dmasz/6*2;
 
-	 for (j = start; j < count - 3; j += nr - 2 ) {
+	 for (j = start; j + 3 < count; j += nr - 2 ) {
 	    nr = MIN2( currentsz, count - j );
 
 	    if (nr >= 4)
@@ -1013,7 +1013,7 @@ static void TAG(render_quad_strip_elts)( GLcontext *ctx,
       else {
 	 ELT_INIT( GL_TRIANGLE_STRIP );
 
-	 for (j = start; j < count - 3; j += nr - 2 ) {
+	 for (j = start; j + 3 < count; j += nr - 2 ) {
 	    nr = MIN2( currentsz, count - j );
 	    TAG(emit_elts)( ctx, elts+j, nr );
 	    NEW_PRIMITIVE();
@@ -1054,7 +1054,7 @@ static void TAG(render_quads_elts)( GLcontext *ctx,
       if (currentsz < 8)
 	 currentsz = dmasz;
 
-      for (j = start; j < count - 3; j += nr - 2 ) {
+      for (j = start; j + 3 < count; j += nr - 2 ) {
 	 nr = MIN2( currentsz, count - j );
 
 	 if (nr >= 4)
